# Invoice

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**amount_due** | **str** |  | [optional] 
**amount_paid** | **str** |  | [optional] 
**amount_remaining** | **str** |  | [optional] 
**auto_advance** | **bool** |  | [optional] 
**billing_reason** | **str** |  | [optional] 
**created** | **str** |  | [optional] 
**currency** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**due_date** | **str** |  | [optional] 
**hosted_invoice_url** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**number** | **str** |  | [optional] 
**paid_date** | **str** |  | [optional] 
**period_end** | **str** |  | [optional] 
**period_start** | **str** |  | [optional] 
**status** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


